@@ -1,6 +1,14 @@
 <?php
 
 
+/**
+  * SquirrelMail Multilogin Plugin
+  * Copyright (C) 2003, 2004 Paul Lesneiwski <pdontthink@angrynerds.com>
+  * This program is licensed under GPL. See COPYING for details
+  *
+  */
+
+
 
 // include compatibility plugin
 //
@@ -97,7 +105,7 @@ function multilogin_insertIMAPSelection_do()
 
    echo "<BR><CENTER>\n".
         "<TABLE COLS=\"1\" WIDTH=\"350\">\n".
-        "  <TR><TD BGCOLOR=\"#FFFFFF\"><TABLE COLS=2 WIDTH=\"100%\">\n".
+        "  <TR><TD BGCOLOR=\"#888888\"><TABLE COLS=2 WIDTH=\"100%\">\n".
         "  <TR>\n".
         "    <TD WIDTH='30%' ALIGN=right>" . _($IMAPServerSelectionText) . ":</TD>\n".
         "    <TD WIDTH=\"*\" ALIGN=left>\n".
@@ -165,9 +173,49 @@ function multilogin_sqoverride_config_do()
          {
             foreach ($value as $pluginName)
             {
+
+               // changing the hook function array whilst in the
+               // middle of iterating thru it for the same hook
+               // doesn't always work, so we'll see if the hook
+               // currently being executed has had its function
+               // list changed; if so, we will execute the added
+               // hook functions ourselves
+//TODO: use $currentHookName instead of this backtrace hassle when $currentHookName
+//      is part of more than just SM 1.5.1 (or part of compatibility plugin?)
+               //
+               $hookName = '';
+               $backtrace = debug_backtrace();
+               foreach ($backtrace as $trace)
+                  if ($trace['function'] == 'do_hook'
+                   || $trace['function'] == 'do_hook_function'
+                   || $trace['function'] == 'concat_hook_function'
+                   || $trace['function'] == 'boolean_hook_function')
+                     $hookName = $trace['args'][0];
+
+               if (!empty($hookName))
+                  $originalHookFunctions = $squirrelmail_plugin_hooks[$hookName];
+
                $plugins[] = $pluginName;
                if (function_exists('use_plugin'))
                   use_plugin($pluginName);
+
+               // now get any new plugins for the current hook
+               // and run their hooks
+               //
+               if (!empty($hookName))
+               {
+                  $newHookFunctions = array_diff($squirrelmail_plugin_hooks[$hookName], 
+                                                 $originalHookFunctions);
+                  foreach ($newHookFunctions as $function)
+                     if (function_exists($function))
+// TODO: currently this code never gets run in a hook that needs data
+//       passed to it or needs to return something, so the following 
+//       call is fine, but if that ever changes, we'll need to get
+//       the other function args from the backtrace and make the right
+//       kind of call, etc.
+                        $function();
+               }
+
             }
             continue;
          }
