@@ -1,5 +1,14 @@
 <?php
 
+
+/**
+  * SquirrelMail Login Multilogin
+  * Copyright (C) 2003, 2004 Paul Lesneiwski <pdontthink@angrynerds.com>
+  * This program is licensed under GPL. See COPYING for details
+  *
+  */
+
+
 function squirrelmail_plugin_init_multilogin() {
 
    global $squirrelmail_plugin_hooks;
@@ -17,55 +26,53 @@ function squirrelmail_plugin_init_multilogin() {
 
 
 
+if (!defined('SM_PATH'))
+   define('SM_PATH', '../');
+
+
+
 function multilogin_version()
 {
-   return '2.2';
+   return '2.3.1';
 }
 
 
 
-// store the user's IMAP server in the session
-//
+/**
+  * store the user's IMAP server in the session
+  *
+  */
 function multilogin_registerIMAPServer()
 {
 
-   if (defined('SM_PATH'))
-      include_once(SM_PATH . 'plugins/multilogin/functions.php');
-   else
-      include_once('../plugins/multilogin/functions.php');
-
+   include_once(SM_PATH . 'plugins/multilogin/functions.php');
    multilogin_registerIMAPServer_do();
 
 }
 
 
-
-// present IMAP server selection pull-down
-//
+/**
+  * present IMAP server selection pull-down
+  *
+  */
 function multilogin_insertIMAPSelection()
 {
 
-   if (defined('SM_PATH'))
-      include_once(SM_PATH . 'plugins/multilogin/functions.php');
-   else
-      include_once('../plugins/multilogin/functions.php');
-
+   include_once(SM_PATH . 'plugins/multilogin/functions.php');
    multilogin_insertIMAPSelection_do();
 
 }
 
 
 
-// present IMAP server selection pull-down
-//
+/**
+  * present IMAP server selection pull-down
+  *
+  */
 function multilogin_sqoverride_config()
 {
 
-   if (defined('SM_PATH'))
-      include_once(SM_PATH . 'plugins/multilogin/functions.php');
-   else
-      include_once('../plugins/multilogin/functions.php');
-
+   include_once(SM_PATH . 'plugins/multilogin/functions.php');
    multilogin_sqoverride_config_do();
 
 }
